// -*- C++ -*- std header                                                      |
//-----------------------------------------------------------------------------+
//                                                                             |
// kern.h                                                                      |
//                                                                             |
// C++ code                                                                    |
//                                                                             |
// Copyright Walter Dehnen, 2000-2001                                          |
// e-mail:   dehnen@mpia.de                                                    |
// address:  Max-Planck Institut fuer Astronomie,                              |
//           Koenigstuhl 17, D-69117 Heidelberg, Germany                       |
//                                                                             |
//-----------------------------------------------------------------------------+
//                                                                             |
// 11/06/2002 kernels Fn and Kn disabled                                       |
//-----------------------------------------------------------------------------+
#ifndef included_kern_h
#define included_kern_h 1

#ifndef included_iostream
#include <iostream>
#define included_iostream
#endif

namespace nbdy {
  //////////////////////////////////////////////////////////////////////////////
  // enum nbdy::tree_soft_type                                                  
  //////////////////////////////////////////////////////////////////////////////
  enum soft_type {                         // type of softening                 
    global      = 0,                       // global eps                        
    individual  = 1                        // use individual eps                
  };                                       //                                   
  //////////////////////////////////////////////////////////////////////////////
  // enum nbdy::kern_type                                                       
  //////////////////////////////////////////////////////////////////////////////
  enum kern_type {                         // type of kernel                    
    newton,                                // no softening                      
    p0, p1, p2, p3                         // Plummer family of kernels         
  };                                       // (p0=standard Plummer softening)   
  //----------------------------------------------------------------------------
  inline nbdy::kern_type kern(const int KERN) {
    switch(KERN % 10) { 
    case  0: return p0;
    case  1: return p1;
    case  2: return p2;
    case  3: return p3;
    case  9: return nbdy::newton;
    default: std::cerr<<" WARNING: kernel unknown, defaulting to Newtonian\n";
      return newton;
    }
  }
}
//------------------------------------------------------------------------------
#endif // included_kern_h
